using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

namespace BeerTaster
{
	/// <summary>
	/// Summary description for EditForm.
	/// </summary>
	public class EditForm : System.Windows.Forms.Form
	{
        private System.Windows.Forms.Label label1;
        private System.Windows.Forms.Label label2;
        private System.Windows.Forms.Label label3;
        private System.Windows.Forms.TextBox nameTextBox;
        private System.Windows.Forms.TextBox countryTextBox;
        private System.Windows.Forms.ComboBox typeComboBox;
        private System.Windows.Forms.NumericUpDown ratingUpDown;
        private System.Windows.Forms.MainMenu mainMenu;
        private System.Windows.Forms.MenuItem toolsMenuItem;
        private System.Windows.Forms.MenuItem deleteMenuItem;
        private System.Windows.Forms.Label label4;
        private Microsoft.WindowsCE.Forms.InputPanel inputPanel;

        private DataRow beerRow;

		public EditForm(DataTable beerTable,int rowIndex)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

            if (rowIndex < 0) 
            {
                beerRow = beerTable.NewRow();
                beerTable.Rows.Add(beerRow);
            }
            else 
            {
                beerRow = beerTable.Rows[rowIndex];
            }
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.label1 = new System.Windows.Forms.Label();
            this.label2 = new System.Windows.Forms.Label();
            this.label3 = new System.Windows.Forms.Label();
            this.label4 = new System.Windows.Forms.Label();
            this.inputPanel = new Microsoft.WindowsCE.Forms.InputPanel();
            this.nameTextBox = new System.Windows.Forms.TextBox();
            this.countryTextBox = new System.Windows.Forms.TextBox();
            this.typeComboBox = new System.Windows.Forms.ComboBox();
            this.ratingUpDown = new System.Windows.Forms.NumericUpDown();
            this.mainMenu = new System.Windows.Forms.MainMenu();
            this.toolsMenuItem = new System.Windows.Forms.MenuItem();
            this.deleteMenuItem = new System.Windows.Forms.MenuItem();
            // 
            // label1
            // 
            this.label1.Location = new System.Drawing.Point(8, 16);
            this.label1.Text = "Name";
            // 
            // label2
            // 
            this.label2.Location = new System.Drawing.Point(8, 40);
            this.label2.Text = "Country";
            // 
            // label3
            // 
            this.label3.Location = new System.Drawing.Point(8, 64);
            this.label3.Text = "Type";
            // 
            // label4
            // 
            this.label4.Location = new System.Drawing.Point(8, 88);
            this.label4.Text = "Rating";
            // 
            // nameTextBox
            // 
            this.nameTextBox.Location = new System.Drawing.Point(112, 8);
            this.nameTextBox.Text = "";
            // 
            // countryTextBox
            // 
            this.countryTextBox.Location = new System.Drawing.Point(112, 32);
            this.countryTextBox.Text = "";
            // 
            // typeComboBox
            // 
            this.typeComboBox.Items.Add("Lager");
            this.typeComboBox.Items.Add("Ale");
            this.typeComboBox.Items.Add("White");
            this.typeComboBox.Items.Add("Blond");
            this.typeComboBox.Items.Add("Red");
            this.typeComboBox.Items.Add("Trappist");
            this.typeComboBox.Items.Add("Stout");
            this.typeComboBox.Location = new System.Drawing.Point(112, 56);
            // 
            // ratingUpDown
            // 
            this.ratingUpDown.Location = new System.Drawing.Point(112, 88);
            this.ratingUpDown.Maximum = new System.Decimal(new int[] {
                                                                         5,
                                                                         0,
                                                                         0,
                                                                         0});
            this.ratingUpDown.Minimum = new System.Decimal(new int[] {
                                                                         1,
                                                                         0,
                                                                         0,
                                                                         0});
            this.ratingUpDown.Size = new System.Drawing.Size(64, 20);
            this.ratingUpDown.Value = new System.Decimal(new int[] {
                                                                       1,
                                                                       0,
                                                                       0,
                                                                       0});
            // 
            // mainMenu
            // 
            this.mainMenu.MenuItems.Add(this.toolsMenuItem);
            // 
            // toolsMenuItem
            // 
            this.toolsMenuItem.MenuItems.Add(this.deleteMenuItem);
            this.toolsMenuItem.Text = "Tools";
            // 
            // deleteMenuItem
            // 
            this.deleteMenuItem.Text = "Delete Beer";
            this.deleteMenuItem.Click += new System.EventHandler(this.deleteMenuItem_Click);
            // 
            // EditForm
            // 
            this.Controls.Add(this.ratingUpDown);
            this.Controls.Add(this.typeComboBox);
            this.Controls.Add(this.countryTextBox);
            this.Controls.Add(this.nameTextBox);
            this.Controls.Add(this.label4);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.label2);
            this.Controls.Add(this.label1);
            this.Menu = this.mainMenu;
            this.MinimizeBox = false;
            this.Text = "EditForm";
            this.Closing += new System.ComponentModel.CancelEventHandler(this.EditForm_Closing);
            this.Load += new System.EventHandler(this.EditForm_Load);

        }
		#endregion

        private void deleteMenuItem_Click(object sender, System.EventArgs e)
        {
            // This is an unrecoverable operation (at least the way I'm doing it here)
            // so make sure the user really wants to do this
            if (MessageBox.Show("Are you sure you want to delete this beer?", "Deleting Beer",
                MessageBoxButtons.YesNo,MessageBoxIcon.Question,
                MessageBoxDefaultButton.Button1) == DialogResult.No)
            {
                return;
            }

            beerRow.Delete();
            this.Close();
        }

        private void EditForm_Load(object sender, System.EventArgs e)
        {
            nameTextBox.Text = beerRow["Name"].ToString();
            countryTextBox.Text = beerRow["Country"].ToString();
            typeComboBox.Text = beerRow["Type"].ToString();

            if (beerRow["Rating"].ToString() == string.Empty) 
            {
                ratingUpDown.Value = 1;
            }
            else
            {
                ratingUpDown.Value = decimal.Parse(beerRow["Rating"].ToString());
            }

            // Have to enable input panel after form creation. Setting the property
            // in the property inspector doesn't work
            inputPanel.Enabled = true;
        }

        private void EditForm_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            if (beerRow.RowState != DataRowState.Deleted)
            {
                // Save changes to record
                beerRow["Name"] = nameTextBox.Text;
                beerRow["Country"] = countryTextBox.Text;
                beerRow["Type"] = typeComboBox.Text;
                beerRow["Rating"] = ratingUpDown.Value;
            }

            // Commit changes
            beerRow.Table.DataSet.AcceptChanges();
            // Hide input panel again, otherwise it will display on the mainform
            inputPanel.Enabled = false;
        }
	}
}
